==> vue-year-table-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["pick", "changerange"],
  props: [].concat(props, ["disabledDate", "value", "defaultValue", "date", "selectionMode", "startYear", "maxDate", "minDate", "rangeState"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    staticClass: "text-xs -m-px border-collapse w-full table-fixed",
    attrs: {
      "data-tag": "tiny-year-table"
    },
    on: {
      "mousemove": _vm.handleMouseMove,
      "click": _vm.handleYearTableClick
    }
  }, [_c("tbody", _vm._l(_vm.state.rows, function(row, trKey) {
    return _c("tr", {
      key: trKey
    }, _vm._l(row, function(cell, tdKey) {
      return _c("td", {
        key: tdKey,
        staticClass: "text-center cursor-pointer py-4 px-0"
      }, [_c("div", {
        class: _vm.m(cell.inRange ? "bg-color-brand-hover-subtle hover:bg-color-brand-hover-subtle" : "h-auto p-0", {
          "rounded-tl rounded-bl": cell.start
        }, {
          "rounded-tr rounded-br mr-5": cell.end
        })
      }, [_c("a", {
        class: _vm.m("w-12 h-12 leading-[theme(spacing.12)] box-border block text-color-text-primary my-0 rounded hover:bg-color-brand-hover-subtle", {
          "border border-solid border-color-border-focus leading-[46px]": _vm.state.currentYear === cell.text
        }, {
          "my-0 mx-auto": !cell.inRange
        }, {
          "text-color-text-inverse bg-color-brand": cell.start
        }, {
          "text-color-text-inverse bg-color-brand": cell.end
        }, {
          "bg-color-bg-3 cursor-not-allowed text-color-text-disabled hover:text-color-text-disabled hover:bg-color-bg-3": _vm.getIsDisabled(cell.text)
        }, {
          "text-color-text-inverse bg-color-brand hover:text-color-text-inverse hover:bg-color-brand": _vm.getIsCurrent(cell.text) && !_vm.getIsDisabled(cell.text)
        }),
        attrs: {
          "aria-disabled": _vm.getIsDisabled(cell.text) ? true : void 0
        }
      }, [_vm._v(_vm._s(cell.text))])])]);
    }), 0);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-year-table-2.22.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/year-table/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["pick", "changerange"],
  props: [].concat(props, ["disabledDate", "value", "defaultValue", "date", "selectionMode", "startYear", "maxDate", "minDate", "rangeState", "readonly"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("table", {
    staticClass: "text-xs -m-px border-collapse w-full table-fixed",
    attrs: {
      "data-tag": "tiny-year-table"
    },
    on: {
      "mousemove": _vm.handleMouseMove,
      "click": _vm.handleYearTableClick
    }
  }, [_c("tbody", _vm._l(_vm.state.rows, function(row, trKey) {
    return _c("tr", {
      key: trKey
    }, _vm._l(row, function(cell, tdKey) {
      return _c("td", {
        key: tdKey,
        staticClass: "text-center cursor-pointer py-4 px-0"
      }, [_c("div", {
        class: _vm.m(cell.inRange ? "bg-color-brand-hover-subtle hover:bg-color-brand-hover-subtle" : "h-auto p-0", {
          "rounded-tl rounded-bl": cell.start
        }, {
          "rounded-tr rounded-br mr-5": cell.end
        })
      }, [_c("a", {
        class: _vm.m("w-12 h-12 leading-[theme(spacing.12)] box-border block text-color-text-primary my-0 rounded hover:bg-color-brand-hover-subtle", {
          "border border-solid border-color-border-focus leading-[46px]": _vm.state.currentYear === cell.text
        }, {
          "my-0 mx-auto": !cell.inRange
        }, {
          "text-color-text-inverse bg-color-brand": cell.start
        }, {
          "text-color-text-inverse bg-color-brand": cell.end
        }, {
          "bg-color-bg-3 cursor-not-allowed text-color-text-disabled hover:text-color-text-disabled hover:bg-color-bg-3": _vm.getIsDisabled(cell.text)
        }, {
          "text-color-text-inverse bg-color-brand hover:text-color-text-inverse hover:bg-color-brand": _vm.getIsCurrent(cell.text) && !_vm.getIsDisabled(cell.text)
        }),
        attrs: {
          "aria-disabled": _vm.getIsDisabled(cell.text) ? true : void 0
        }
      }, [_vm._v(_vm._s(cell.text))])])]);
    }), 0);
  }), 0)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
